==> hudi-0.10.0.src.tgz: hudi-0.10.0/hudi-client/hudi-spark-client/src/main/java/org/apache/hudi/table/action/bootstrap/BootstrapMetadataHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.table.action.bootstrap;

import org.apache.hudi.client.bootstrap.BootstrapWriteStatus;
import org.apache.hudi.keygen.KeyGeneratorInterface;

/**
 * Bootstrap metadata handler to assist in bootstrapping only metadata.
 */
public interface BootstrapMetadataHandler {
  /**
   * Execute bootstrap with only metatata.
   * @param srcPartitionPath source partition path.
   * @param partitionPath destination partition path.
   * @param keyGenerator key generator to use.
   * @return the {@link BootstrapWriteStatus} which has the result of execution.
   */
  BootstrapWriteStatus runMetadataBootstrap(String srcPartitionPath, String partitionPath, KeyGeneratorInterface keyGenerator);
}

==> hudi-0.12.2.src.tgz: hudi-0.12.2/hudi-client/hudi-spark-client/src/main/java/org/apache/hudi/table/action/bootstrap/BootstrapMetadataHandler.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hudi.table.action.bootstrap;

import org.apache.hudi.client.bootstrap.BootstrapWriteStatus;
import org.apache.hudi.keygen.KeyGeneratorInterface;

/**
 * Bootstrap metadata handler to assist in bootstrapping only metadata.
 */
public interface BootstrapMetadataHandler {
  /**
   * Execute bootstrap with only metadata.
   *
   * @param srcPartitionPath source partition path.
   * @param partitionPath    destination partition path.
   * @param keyGenerator     key generator to use.
   * @return the {@link BootstrapWriteStatus} which has the result of execution.
   */
  BootstrapWriteStatus runMetadataBootstrap(String srcPartitionPath, String partitionPath, KeyGeneratorInterface keyGenerator);
}
